# cjm-byte-track

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

A standalone Python implementation of the
[ByteTrack](https://arxiv.org/abs/2110.06864) multi-object tracker based
on the [official
implementation](https://github.com/ifzhang/ByteTrack/tree/main/yolox/tracker).

## Install

``` sh
pip install cjm_byte_track
```

## How to use
